/* 
 * geotiffio.h
 * 
 * Standard include file for geotiff, including all
 * key and code definitions.
 *
 * copyright (c) 1995   Niles D. Ritter
 *
 * Permission granted to use this software, so long as this copyright
 * notice accompanies any products derived therefrom.
 */


#ifndef LIBGEOTIFF_GEOTIFFIO_H_
#define LIBGEOTIFF_GEOTIFFIO_H_

#include "geotiff.h"  /* public key interface */
#include "geovalues.h" /* key code definitions */

#endif /* LIBGEOTIFF_GEOTIFFIO_H_ */

